==> migrate_wizard-2.0.8-alpha1.tar.gz: migrate_wizard/src/Plugin/Derivative/DynamicMWDatabasesTasks.php <==
<?php
/**
 * @file
 * Handles the automatic generation of migration YAML files.
 *
 * Migrate Wizard - Facilitates migration from Drupal 7 by mapping fields and content types
 * through an interface, without the need for programming.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Migrate Wizard. If not, see <https://www.gnu.org/licenses/>.
 *
 * Author: Carlos Romero Álvarez
 */

namespace Drupal\migrate_wizard\Plugin\Derivative;

use Drupal\Component\Plugin\Derivative\DeriverBase;
use Drupal\Component\Transliteration\PhpTransliteration;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Config\ConfigManager;
use Drupal\Core\Entity\EntityFieldManagerInterface;
use Drupal\Core\Entity\EntityTypeManager;
use Drupal\Core\Extension\ExtensionList;
use Drupal\Core\Plugin\Discovery\ContainerDeriverInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;


/**
 * Defines dynamic local tasks.
 */
class DynamicMWDatabasesTasks extends DeriverBase implements ContainerDeriverInterface {

  private $entityTypeManager;


  public function __construct(EntityTypeManager $entity_type_manager) {
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, $base_plugin_id) {
    return new static(
      $container->get('entity_type.manager'),
    );
  }
  /**
   * {@inheritdoc}
   */
  public function getDerivativeDefinitions($base_plugin_definition) {

    $mw_databases = $this->entityTypeManager->getStorage('mw_database')->loadMultiple();

    foreach($mw_databases as $mw_database){

      $this->derivatives['mw_database.'.$mw_database->id] = $base_plugin_definition;
      $this->derivatives['mw_database.'.$mw_database->id]['base_route'] = 'entity.database.list';
      $this->derivatives['mw_database.'.$mw_database->id]['title'] = $mw_database->id;
      $this->derivatives['mw_database.'.$mw_database->id]['route_name'] = 'entity.origin_users_roles.settings';
      $this->derivatives['mw_database.'.$mw_database->id]['route_parameters'] = ['mw_database' => $mw_database->id];

      $links = [
        'user_roles' => [
          'route_name' => 'entity.origin_users_roles.settings',
          'route_parameters' => ['mw_database' => $mw_database->id],
          'title' => 'Users Roles',
        ],
        'users' => [
          'route_name' => 'entity.origin_users.settings',
          'route_parameters' => ['mw_database' => $mw_database->id, 'origin_bundle' => 'user'],
          'title' => 'Users',
        ],
        'mapping_format_editors' => [
          'route_name' => 'migrate_wizard.mapping',
          'route_parameters' => ['mw_database' => $mw_database->id],
          'title' => 'Mapping format editors',
        ],
        'node_list' => [
          'route_name' => 'entity.origin_node.list',
          'route_parameters' => ['mw_database' => $mw_database->id],
          'title' => 'Node list',
        ],
        'vocabularies_list' => [
          'route_name' => 'entity.origin_vocabularies.list',
          'route_parameters' => ['mw_database' => $mw_database->id],
          'title' => 'Vocabularies list',
        ],
        'field_collection_list' => [
          'route_name' => 'entity.origin_field_collection.list',
          'route_parameters' => ['mw_database' => $mw_database->id],
          'title' => 'Manage Origin Field Collections'
        ],
        'paragraph_list' => [
          'route_name' => 'entity.origin_paragraph.list',
          'route_parameters' => ['mw_database' => $mw_database->id],
          'title' => 'Manage Origin Paragraphs'
        ],
        'migration_files' => [
          'route_name' => 'migrate_wizard.migrate_files.configuration',
          'route_parameters' => ['mw_database' => $mw_database->id],
          'title' => 'Manage Migration files'
        ],
        'migration_medias' => [
          'route_name' => 'entity.origin_medias.list',
          'route_parameters' => ['mw_database' => $mw_database->id],
          'title' => 'Manage Migration Medias'
        ]
      ];
      foreach($links as $link_key => $link){
        $this->derivatives[$link_key.'.'.$mw_database->id] = $base_plugin_definition;
        $this->derivatives[$link_key.'.'.$mw_database->id]['route_name'] = $link['route_name'];
        $this->derivatives[$link_key.'.'.$mw_database->id]['route_parameters'] = $link['route_parameters'];
        $this->derivatives[$link_key.'.'.$mw_database->id]['title'] = $link['title'];
        $this->derivatives[$link_key.'.'.$mw_database->id]['parent_id'] = 'migrate_wizard.current_databases:mw_database.'.$mw_database->id;
      }
    }
    return parent::getDerivativeDefinitions($base_plugin_definition);
  }

}

==> migrate_wizard-2.0.9-alpha1.tar.gz: migrate_wizard/src/Plugin/Derivative/DynamicMWDatabasesTasks.php <==
<?php
/**
 * @file
 * Handles the automatic generation of migration YAML files.
 *
 * Migrate Wizard - Facilitates migration from Drupal 7 by mapping fields and content types
 * through an interface, without the need for programming.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Migrate Wizard. If not, see <https://www.gnu.org/licenses/>.
 *
 * Author: Carlos Romero Álvarez
 */

namespace Drupal\migrate_wizard\Plugin\Derivative;

use Drupal\Component\Plugin\Derivative\DeriverBase;
use Drupal\Core\Entity\EntityTypeManager;
use Drupal\Core\Plugin\Discovery\ContainerDeriverInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Defines dynamic local tasks.
 */
class DynamicMWDatabasesTasks extends DeriverBase implements ContainerDeriverInterface {

  private $entityTypeManager;

  public function __construct(EntityTypeManager $entity_type_manager) {
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, $base_plugin_id) {
    return new static(
      $container->get('entity_type.manager'),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getDerivativeDefinitions($base_plugin_definition) {
    $mw_databases = $this->entityTypeManager->getStorage('mw_database')->loadMultiple();

    foreach ($mw_databases as $mw_database) {
      $this->derivatives['mw_database.' . $mw_database->id] = $base_plugin_definition;
      $this->derivatives['mw_database.' . $mw_database->id]['base_route'] = 'entity.database.list';
      $this->derivatives['mw_database.' . $mw_database->id]['title'] = $mw_database->id;
      $this->derivatives['mw_database.' . $mw_database->id]['route_name'] = 'entity.origin_users_roles.settings';
      $this->derivatives['mw_database.' . $mw_database->id]['route_parameters'] = ['mw_database' => $mw_database->id];

      $links = [
        'user_roles' => [
          'route_name' => 'entity.origin_users_roles.settings',
          'route_parameters' => ['mw_database' => $mw_database->id],
          'title' => 'Users Roles',
        ],
        'users' => [
          'route_name' => 'entity.origin_users.settings',
          'route_parameters' => ['mw_database' => $mw_database->id, 'origin_bundle' => 'user'],
          'title' => 'Users',
        ],
        'mapping_format_editors' => [
          'route_name' => 'migrate_wizard.mapping',
          'route_parameters' => ['mw_database' => $mw_database->id],
          'title' => 'Mapping format editors',
        ],
        'node_list' => [
          'route_name' => 'entity.origin_node.list',
          'route_parameters' => ['mw_database' => $mw_database->id],
          'title' => 'Node list',
        ],
        'vocabularies_list' => [
          'route_name' => 'entity.origin_vocabularies.list',
          'route_parameters' => ['mw_database' => $mw_database->id],
          'title' => 'Vocabularies list',
        ],
        'field_collection_list' => [
          'route_name' => 'entity.origin_field_collection.list',
          'route_parameters' => ['mw_database' => $mw_database->id],
          'title' => 'Manage Origin Field Collections',
        ],
        'paragraph_list' => [
          'route_name' => 'entity.origin_paragraph.list',
          'route_parameters' => ['mw_database' => $mw_database->id],
          'title' => 'Manage Origin Paragraphs',
        ],
        'migration_files' => [
          'route_name' => 'migrate_wizard.migrate_files.configuration',
          'route_parameters' => ['mw_database' => $mw_database->id],
          'title' => 'Manage Migration files',
        ],
        'migration_medias' => [
          'route_name' => 'entity.origin_medias.list',
          'route_parameters' => ['mw_database' => $mw_database->id],
          'title' => 'Manage Migration Medias',
        ],
      ];

      foreach ($links as $link_key => $link) {
        $this->derivatives[$link_key . '.' . $mw_database->id] = $base_plugin_definition;
        $this->derivatives[$link_key . '.' . $mw_database->id]['route_name'] = $link['route_name'];
        $this->derivatives[$link_key . '.' . $mw_database->id]['route_parameters'] = $link['route_parameters'];
        $this->derivatives[$link_key . '.' . $mw_database->id]['title'] = $link['title'];
        $this->derivatives[$link_key . '.' . $mw_database->id]['parent_id'] = 'migrate_wizard.current_databases:mw_database.' . $mw_database->id;
      }
    }

    return parent::getDerivativeDefinitions($base_plugin_definition);
  }

}
